/*
// Program:  Format
// Module:  FORMAT.H
// Module Description:  Free FDISK Header File
// Written By:  Brian E. Reifsnyder
// Version:  0.7
// Copyright:  2001 under the terms of the GNU GPL, Version 2.
*/

/*
/////////////////////////////////////////////////////////////////////////////
//  DEFINES
/////////////////////////////////////////////////////////////////////////////
*/

#ifdef MAIN
#define EXTERN /**/
#else
#define EXTERN extern
#endif

#define MEG 1048576

#define PRIMARY 1
#define EXTENDED 2
#define LOGICAL 3
#define SPECIAL 4

#define LAST 99

#define TRUE  1
#define FALSE 0

#define HARD   0
#define FLOPPY 1

#define FAT12 1
#define FAT16 2
#define FAT32 3


/*
/////////////////////////////////////////////////////////////////////////////
//  GLOBAL VARIABLES
/////////////////////////////////////////////////////////////////////////////
*/

EXTERN char ascii_cd_number[15];
EXTERN char partition_label[16];

/* Buffers */
EXTERN unsigned long bad_sector_map[1024];

EXTERN unsigned char mirror_map[8192];

/* Ending Mapping Variables */
EXTERN long computed_ending_cylinder;
EXTERN unsigned long computed_partition_size;

/* Integers converted from long numbers */
EXTERN int integer3;
EXTERN int integer4;

extern unsigned long translated_cylinder;
extern unsigned long translated_head;
extern unsigned long translated_sector;

/*
/////////////////////////////////////////////////////////////////////////////
//  GLOBAL STRUCTURES
/////////////////////////////////////////////////////////////////////////////
*/

typedef struct Access_Flags
  {
  unsigned char special_function;      /* Set to 0.                        */
  unsigned char disk_access;           /* Set to non-zero to allow access. */
  } AF;

typedef struct Drive_Statistics
  {
  unsigned long bytes_total_disk_space;
  unsigned long bytes_available_on_disk;

  unsigned long bytes_in_each_allocation_unit;
  unsigned long allocation_units_available_on_disk;

  unsigned int serial_number_low;
  unsigned int serial_number_high;
  } DS;

typedef struct Formatting_Parameters
  {
  char drive_letter[2];
  char volume_label[12];

  int drive_type;                 /* FLOPPY or HARD */
  int drive_number;
  int physical_drive_number;
  int partition_number;
  int fat_type;
  int media_type;                 /* FD#### or HD */

  int force_yes;

  int v;
  int q;
  int u;
  int f;
  int b;
  int s;
  int t;
  int n;
  int one;
  int four;
  int eight;

  unsigned long size;
  unsigned long cylinders;
  unsigned long sectors;

  } FP;

typedef struct DDPT_Structure
{
  unsigned step_rate : 4 ;
  unsigned head_unload_time : 4;
  unsigned head_load_time : 7;
  unsigned dma_flag : 1;
  unsigned post_rt_of_disk_motor : 8;
  unsigned sector_size : 8;
  unsigned sectors_per_cylinder : 8;
  unsigned gap3_length_rw : 8;
  unsigned dtl : 8;
  unsigned gap3_length_xmat : 8;
  unsigned fill_char_xmat : 8;
  unsigned head_settle_time : 8;
  unsigned run_up_time : 8;
} DDPT;

typedef struct DPB_Structure {
  unsigned char drive_number;
  unsigned char device_driver_unit_number;
  unsigned int  bytes_per_sector;
  unsigned char sectors_per_cluster_minus_one;
  unsigned char sectors_per_cluster_power_two;
  unsigned int  beginning_fat_sector;
  unsigned char number_fat_copies;
  unsigned int  number_root_directory_entries;
  unsigned int  first_data_cluster;
  unsigned int  number_clusters_plus_one;
  unsigned int  sectors_per_fat;
  unsigned int  first_root_directory_sector;
  unsigned long device_driver_address;
  unsigned char media_descriptor;
  unsigned char dpb_access_flag;
  unsigned long next_dpb_pointer;
  unsigned int  last_cluster_allocated;
  unsigned int  number_free_clusters;
  }DPB;

typedef struct Track_Address_Field_Structure
{
  unsigned cylinder : 8;
  unsigned head : 8;
  unsigned sector : 8;
  unsigned size_code : 8;
} TAF;

typedef struct Low_Level_Format_Values_Structure
{
  int interleave_factor;
  int interleave_index;
  int interleave_map[64];
} LLFVS;

typedef struct Parameter_Block_Structure
{
  /* unsigned special_functions         :  8; */
  unsigned use_current_bpb           :  1;
  unsigned use_track_layout_fields   :  1;
  unsigned all_sectors_same_size     :  1;
  unsigned reserved                  :  5;

  unsigned device_type               :  8;
  unsigned device_attributes         : 16;
  unsigned number_of_cylinders       : 16;
  unsigned media_type                :  8;
  /* BPB Follows */
  unsigned bytes_per_sector          : 16;
  unsigned sectors_per_cluster       :  8;
  unsigned reserved_sectors          : 16;
  unsigned number_of_fats            :  8;
  unsigned root_directory_entries    : 16;
  unsigned total_sectors             : 16;
  unsigned media_descriptor          :  8;
  unsigned sectors_per_fat           : 16;
  unsigned sectors_per_cylinder      : 16;
  unsigned number_of_heads           : 16;
  unsigned hidden_sectors_low        : 16;
  unsigned hidden_sectors_high       : 16;
  unsigned large_sector_count_low    : 16;
  unsigned large_sector_count_high   : 16;
}PB;

EXTERN AF far access_flags;
EXTERN DPB far *dpb;
EXTERN DS drive_statistics;
EXTERN FP param;
EXTERN PB parameter_block;
EXTERN DDPT far *ddpt;
EXTERN LLFVS low_level;



